@@ -78,6 +78,13 @@ curl -X PUT --data "${new}" $uri -H "Metadata-Flavor: Google"
 	linuxLocalPrePatchScript = `
 echo 'curl -X PUT --data "1" http://metadata.google.internal/computeMetadata/v1/instance/guest-attributes/osconfig_tests/pre_step_ran -H "Metadata-Flavor: Google"' >> ./linux_local_pre_patch_script.sh
 chmod +x ./linux_local_pre_patch_script.sh
+`
+
+	setUpDowngradeState = `
+echo 'deb [trusted=yes check-valid-until=no] http://snapshot.debian.org/archive/debian/20190801T025637Z/ buster main' >> /etc/apt/sources.list
+echo 'Package: sudo' >> /etc/apt/preferences
+echo 'Pin: version 1.8.27-1' >> /etc/apt/preferences
+echo 'Pin-priority: 9999' >> /etc/apt/preferences
 `
 
 	enableOsconfig  = compute.BuildInstanceMetadataItem("enable-osconfig", "true")
@@ -102,6 +109,15 @@ chmod +x ./linux_local_pre_patch_script.sh
 		},
 		machineType: "e2-medium",
 	}
+	aptDowngradeSetup = &patchTestSetup{
+		assertTimeout: 10 * time.Minute,
+		metadata: []*computeApi.MetadataItems{
+			compute.BuildInstanceMetadataItem("startup-script", linuxRecordBoot+utils.InstallOSConfigDeb()+linuxLocalPrePatchScript+setUpDowngradeState),
+			enableOsconfig,
+			disableFeatures,
+		},
+		machineType: "e2-medium",
+	}
 	el6Setup = &patchTestSetup{
 		assertTimeout: 15 * time.Minute,
 		metadata: []*computeApi.MetadataItems{
@@ -189,6 +205,15 @@ func aptHeadImageTestSetup() []*patchTestSetup {
 	return imageTestSetup(mapping)
 }
 
+func aptDowngradeImageTestSetup() []*patchTestSetup {
+	// This maps a specific patchTestSetup to test setup names and associated images.
+	mapping := map[*patchTestSetup]map[string]string{
+		aptDowngradeSetup: utils.DowngradeAptImages,
+	}
+
+	return imageTestSetup(mapping)
+}
+
 func yumHeadImageTestSetup() []*patchTestSetup {
 	// This maps a specific patchTestSetup to test setup names and associated images.
 	mapping := map[*patchTestSetup]map[string]string{
