@@ -15,7 +15,6 @@
 package packages
 
 import (
-	"context"
 	"errors"
 	"os/exec"
 	"reflect"
@@ -52,7 +51,7 @@ func TestInstalledRPMPackages(t *testing.T) {
 
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
-	expectedCmd := exec.CommandContext(context.Background(), rpmquery, rpmqueryInstalledArgs...)
+	expectedCmd := utilmocks.EqCmd(exec.Command(rpmquery, rpmqueryInstalledArgs...))
 
 	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("foo x86_64 1.2.3-4"), []byte("stderr"), nil).Times(1)
 	ret, err := InstalledRPMPackages(testCtx)
@@ -78,7 +77,7 @@ func TestRPMPkgInfo(t *testing.T) {
 	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
 	runner = mockCommandRunner
 	testPkg := "test.rpm"
-	expectedCmd := exec.CommandContext(context.Background(), rpmquery, append(rpmqueryRPMArgs, testPkg)...)
+	expectedCmd := utilmocks.EqCmd(exec.Command(rpmquery, append(rpmqueryRPMArgs, testPkg)...))
 
 	mockCommandRunner.EXPECT().Run(testCtx, expectedCmd).Return([]byte("foo x86_64 1.2.3-4"), []byte("stderr"), nil).Times(1)
 	ret, err := RPMPkgInfo(testCtx, testPkg)
