@@ -18,9 +18,12 @@ import (
 	"bytes"
 	"context"
 	"fmt"
+	"os"
 	"os/exec"
 	"runtime"
+	"strings"
 
+	"github.com/GoogleCloudPlatform/osconfig/clog"
 	"github.com/GoogleCloudPlatform/osconfig/osinfo"
 	"github.com/GoogleCloudPlatform/osconfig/util"
 )
@@ -131,6 +134,25 @@ func parseYumUpdates(data []byte) []*PkgInfo {
 	return pkgs
 }
 
+func getYumTXFile(data []byte) string {
+	/* The last lines of a non-complete yum update where the transaction
+	   is saved look like:
+
+	     Exiting on user command
+	     Your transaction was saved, rerun it with:
+	      yum load-transaction /tmp/yum_save_tx.2022-10-12.20-26.j3auah.yumtx
+	*/
+	lines := bytes.Split(bytes.TrimSpace(data), []byte("\n"))
+
+	for _, ln := range lines {
+		flds := bytes.Fields(ln)
+		if len(flds) == 3 && string(flds[1]) == "load-transaction" && strings.HasPrefix(string(flds[2]), "/tmp/yum_save_tx.") {
+			return string(flds[2])
+		}
+	}
+	return ""
+}
+
 // YumUpdates queries for all available yum updates.
 func YumUpdates(ctx context.Context, opts ...YumUpdateOption) ([]*PkgInfo, error) {
 	// We just use check-update to ensure all repo keys are synced as we run
@@ -180,6 +202,16 @@ func listAndParseYumPackages(ctx context.Context, opts ...YumUpdateOption) ([]*P
 		return nil, nil
 	}
 
+	// Some versions of yum will leave a transaction file in /tmp when update
+	// is run with --assumeno. This will attempt to delete that file.
+	yumTXFile := getYumTXFile(stdout)
+	if yumTXFile != "" {
+		clog.Debugf(ctx, "Removing yum tx file: %s", yumTXFile)
+		if err := os.Remove(yumTXFile); err != nil {
+			clog.Debugf(ctx, "Error deleting yum tx file %s: %v", yumTXFile, err)
+		}
+	}
+
 	pkgs := parseYumUpdates(stdout)
 	if len(pkgs) == 0 {
 		// This means we could not parse any packages and instead got an error from yum.
